import React, { Component } from "react";
import {Alert, FlatList, StyleSheet, Text, View, TouchableOpacity} from 'react-native'
import {MapView, Marker} from 'react-native-amap3d'

export default class MapPageDemo extends Component {
    constructor(props) {
        super(props);
         this._loadData(1, 0 , 0);
    }
    state = {
        dataSource:[]
    }
    _loadData(level, latitude, longitude) {
        var me = this;
        var requestURL = 'https://www.easy-mock.com/mock/59c5d451e0dc663341b5c9f9/fg/api/v1/map/search/area';;

        fetch(requestURL)
          .then((response) => response.json())
          .then((responseJson) => {
                this.setState({
                    lastReqType:level,
                    dataSource: responseJson.data.list,
                    });
          })
          .catch((error) => {
            console.error(error);
          });
    }

    _renderMarker(){
        return this.state.dataSource.map(function(dataItem, index){
            var location = {
                latitude: dataItem.latitude,
                longitude: dataItem.longitude,
            };
            var markerStyle = styles.customMarker1;

           return(
               <Marker
                   key = {index}
                   icon={() =>
                       <View style={markerStyle}>
                           <Text style={styles.markerText}>{dataItem.name}</Text>
                           <Text style={styles.markerText}>{dataItem.desc}</Text>
                       </View>
                   }
                   coordinate={location}
                   onPress={() => this._onMarkerViewPress(dataItem.latitude, dataItem.longitude)}
                   clickable = {this.state.markerType == 3?false:true}
                   infoWindowEnabled = {false}
                   draggable = {true}
                   flat = {true}
               />
           );
       }, this);
    }

    render() {
        return (
            <View style={styles.body}>
                <MapView
                    ref={(c) => this._mapView = c}
                    locationEnabled
                    locationInterval={10000}
                    distanceFilter={100}
                    showsZoomControls = {true}
                    showsLocationButton = {true}
                    maxZoomLevel = {18}
                    minZoomLevel = {5}
                    onStatusChangeComplete={this._mapStatusChangeCompleteEvent}
                    style={styles.mapview}
                    >
                    {this._renderMarker()}
                </MapView>
            </View>
        );
    }
}

const styles = StyleSheet.create({
    body: {
        flex: 1,
    },
    mapview: {
        flex: 1,
    },
    customMarker1: {
      alignItems: 'center',
      justifyContent: 'center',
      width: 80,
      height: 80,
      borderRadius: 40,
      backgroundColor: 'rgba(50, 205, 50, 0.8)',
    },
    markerText: {
      color: '#fff',
    },
})
